@@ -1,4 +1,4 @@
-__version_info__ = (1, 1, 11)
+__version_info__ = (1, 1, 12)
 __version__ = ".".join(map(str, __version_info__))
 ALL = ["objict"]
 import sys
@@ -278,7 +278,9 @@ class objict(dict):
                 return cls()
 
         jmsg = json.loads(json_string)
-        return cls.fromdict(jmsg)
+        if isinstance(jmsg, dict):
+            return cls.fromdict(jmsg)
+        return jmsg
 
     @classmethod
     def fromXML(cls, xml):
